@@ -18,12 +18,12 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'CFLAGS': '-fno-strict-aliasing -OPT:Olimit=0 -O2 -pipe -DNDEBUG -O2 -pipe   -fPIC',
  'CFLAGSFORSHARED': '-fPIC',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
- 'CONFIG_ARGS': "'--with-ensurepip=no' '--enable-shared' '--srcdir=/usr/obj/ports/Python-2.7.15/Python-2.7.15' '--with-fpectl' '--with-threads' '--enable-ipv6' '--with-system-expat' '--with-system-ffi' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' '--localstatedir=/var' '--disable-silent-rules' '--disable-gtk-doc' 'CC=cc' 'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib/' 'CPPFLAGS=-I/usr/local/include'",
+ 'CONFIG_ARGS': "'--with-ensurepip=no' '--enable-shared' '--srcdir=/usr/obj/ports/Python-2.7.16/Python-2.7.16' '--with-fpectl' '--with-threads' '--enable-ipv6' '--with-system-expat' '--with-system-ffi' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' '--localstatedir=/var' '--disable-silent-rules' '--disable-gtk-doc' 'CC=cc' 'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib/' 'CPPFLAGS=-I/usr/local/include'",
  'CONFINCLUDEDIR': '/usr/local/include',
  'CONFINCLUDEPY': '/usr/local/include/python2.7',
  'COREPYTHONPATH': ':plat-openbsd6:lib-tk:lib-old',
- 'COVERAGE_INFO': '/usr/obj/ports/Python-2.7.15/Python-2.7.15/coverage.info',
- 'COVERAGE_REPORT': '/usr/obj/ports/Python-2.7.15/Python-2.7.15/lcov-report',
+ 'COVERAGE_INFO': '/usr/obj/ports/Python-2.7.16/Python-2.7.16/coverage.info',
+ 'COVERAGE_REPORT': '/usr/obj/ports/Python-2.7.16/Python-2.7.16/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov report"',
  'CPPFLAGS': '-I. -IInclude -I./Include -I/usr/local/include',
  'CXX': 'c++ -pthread',
@@ -141,7 +141,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_FTRUNCATE': 1,
  'HAVE_GAI_STRERROR': 1,
  'HAVE_GAMMA': 1,
- 'HAVE_GCC_ASM_FOR_X87': 0,
+ 'HAVE_GCC_ASM_FOR_X87': 1,
  'HAVE_GETADDRINFO': 1,
  'HAVE_GETCWD': 1,
  'HAVE_GETC_UNLOCKED': 1,
@@ -187,7 +187,6 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_LANGINFO_H': 1,
  'HAVE_LARGEFILE_SUPPORT': 0,
  'HAVE_LCHFLAGS': 0,
- 'HAVE_LCHMOD': 0,
  'HAVE_LCHOWN': 1,
  'HAVE_LGAMMA': 1,
  'HAVE_LIBDL': 0,
@@ -357,16 +356,16 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_WORKING_TZSET': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HOST_GNU_TYPE': 'aarch64-unknown-openbsd6.4',
+ 'HOST_GNU_TYPE': 'x86_64-unknown-openbsd6.6',
  'HURD_C_THREADS': 0,
  'INCLDIRSTOMAKE': '/usr/local/include /usr/local/include /usr/local/include/python2.7 /usr/local/include/python2.7',
  'INCLUDEDIR': '/usr/local/include',
  'INCLUDEPY': '/usr/local/include/python2.7',
- 'INSTALL': '/usr/obj/ports/Python-2.7.15/bin/install -c',
- 'INSTALL_DATA': '/usr/obj/ports/Python-2.7.15/bin/install -c -m 644',
- 'INSTALL_PROGRAM': '/usr/obj/ports/Python-2.7.15/bin/install -c -s -m 755',
- 'INSTALL_SCRIPT': '/usr/obj/ports/Python-2.7.15/bin/install -c -m 755',
- 'INSTALL_SHARED': '/usr/obj/ports/Python-2.7.15/bin/install -c -m 555',
+ 'INSTALL': '/usr/obj/ports/Python-2.7.16/bin/install -c',
+ 'INSTALL_DATA': '/usr/obj/ports/Python-2.7.16/bin/install -c -m 644',
+ 'INSTALL_PROGRAM': '/usr/obj/ports/Python-2.7.16/bin/install -c -s -m 755',
+ 'INSTALL_SCRIPT': '/usr/obj/ports/Python-2.7.16/bin/install -c -m 755',
+ 'INSTALL_SHARED': '/usr/obj/ports/Python-2.7.16/bin/install -c -m 555',
  'INSTSONAME': 'libpython2.7.so.0.0',
  'LDCXXSHARED': 'c++ -pthread -shared -fPIC',
  'LDFLAGS': '-L/usr/local/lib/',
@@ -465,7 +464,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'RANLIB': 'ranlib',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-2.7.15/Python-2.7.15',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-2.7.16/Python-2.7.16',
  'SCRIPTDIR': '/usr/local/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SGI_ABI': '',
@@ -508,7 +507,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'TESTOPTS': '-l',
  'TESTPATH': '',
  'TESTPROG': './Lib/test/regrtest.py',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-2.7.15/Python-2.7.15 ./python -Wd -3 -E -tt',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-2.7.16/Python-2.7.16 ./python -Wd -3 -E -tt',
  'TESTPYTHONOPTS': '',
  'THREADOBJ': 'Python/thread.o',
  'TIME_WITH_SYS_TIME': 1,
@@ -518,7 +517,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'UNIVERSALSDK': '',
  'USE_COMPUTED_GOTOS': 0,
  'USE_TOOLBOX_OBJECT_GLUE': 0,
- 'VA_LIST_IS_ARRAY': 0,
+ 'VA_LIST_IS_ARRAY': 1,
  'VERSION': '2.7',
  'WANT_SIGFPE_HANDLER': 1,
  'WANT_WCTYPE_FUNCTIONS': 0,
@@ -533,11 +532,11 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/usr/obj/ports/Python-2.7.15/Python-2.7.15',
- 'abs_srcdir': '/usr/obj/ports/Python-2.7.15/Python-2.7.15',
- 'build': 'aarch64-unknown-openbsd6.4',
+ 'abs_builddir': '/usr/obj/ports/Python-2.7.16/Python-2.7.16',
+ 'abs_srcdir': '/usr/obj/ports/Python-2.7.16/Python-2.7.16',
+ 'build': 'x86_64-unknown-openbsd6.6',
  'datarootdir': '/usr/local/share',
  'exec_prefix': '/usr/local',
- 'host': 'aarch64-unknown-openbsd6.4',
+ 'host': 'x86_64-unknown-openbsd6.6',
  'prefix': '/usr/local',
  'srcdir': '.'}
